==> side_menu_v2.0.1.tar.gz: side_menu/l10n/zh_CN.js <==
OC.L10N.register("side_menu", {
    "Custom menu": "自定义菜单",
    "Enable the custom menu": "激活自定义菜单",
    "No": "取消",
    "Yes": "确定",
    "Menu": "菜单",
    "Use the shortcut <span class=\"keyboard-key\">Ctrl<\/span>+<span class=\"keyboard-key\">o<\/span> to open and to hide the side menu. Use <span class=\"keyboard-key\">tab<\/span> to navigate.": "使用快捷键 <span class=\"keyboard-key\">Ctrl<\/span>+<span class=\"keyboard-key\">o<\/span> 打开或隐藏侧边栏菜单。使用<span class=\"keyboard-key\">tab<\/span> 来导航。",
    "Top menu": "顶部菜单",
    "Apps that not must be moved in the side menu": "禁止在侧边栏菜单移动的应用",
    "If there is no selection then the global configuration is applied.": "如不选择，将应用全局设定。",
    "Experimental": "实验性",
    "Save": "保存",
    "You like this app and you want to support me?": "喜欢本应用并支持我一下？",
    "Buy me a coffee ☕": "赏一杯咖啡 ☕ 给我",
    "Hidden": "隐藏",
    "Small": "小型",
    "Normal": "标准",
    "Big": "大型",
    "Colors": "颜色",
    "Background color": "背景颜色",
    "Background color of current app": "当前应用的背景色",
    "Text color": "文字颜色",
    "Loader": "菜单指示器",
    "Icon": "图标",
    "Same color": "相同颜色",
    "Opposite color": "相反颜色",
    "Transparent": "透明",
    "Opaque": "不透明",
    "Opener": "容器",
    "Default": "默认",
    "Default (dark)": "默认(深色)",
    "Hamburger": "Hamburger",
    "Hamburger (dark)": "Hamburger (深色)",
    "Hamburger 2": "Hamburger 2",
    "Hamburger 2 (dark)": "Hamburger 2 (深色)",
    "Before the logo": "在logo前",
    "After the logo": "在logo后",
    "Position": "位置",
    "Show only the opener (hidden logo)": "只显示容器 (隐藏logo)",
    "Do not display the side menu and the opener if there is no application (eg: public pages).": "N如果没有应用，不显示侧边栏菜单和容器 (例如 : 公共页面)。",
    "Panel": "面板",
    "Open the menu when the mouse is hover the opener (automatically disabled on touch screens)": "鼠标悬停时打开菜单 (触摸屏时将自动禁用)",
    "Display the big menu": "显示大型菜单",
    "This menu is not compatible with AppOrder.": "型菜单与应用顺序不兼容",
    "Display the logo": "显示logo",
    "This feature is not compatible with the <code>big menu<\/code> display.": "此功能与显示<code>大型菜单<\/code>不兼容。",
    "Icons and texts": "图标与文字",
    "Loader enabled": "菜单指示器已激活",
    "Tips": "技巧",
    "Always displayed": "一直显示",
    "The logo will be hidden when the menu is always displayed.": "一直显示菜单时logo将被隐藏。",
    "This is the automatic behavior when the menu is always displayed.": "一直显示菜单时的自动动作。",
    "Not compatible with touch screens.": "与触屏不兼容。",
    "Big menu": "大型菜单",
    "Live preview": "实时预览",
    "Open apps in new tab": "在新标签中打开应用",
    "Use the global setting": "使用全局设定",
    "Use my selection": "使用自定义设定",
    "Show and hide the list of applications": "显示或隐藏应用列表",
    "Use the avatar instead of the logo": "使用头像代替logo",
    "You do not have permission to change the settings.": "没有更改设置的权限。",
    "Force this configuration to users": "强制用户使用此设置",
    "Export the configuration": "导出设置",
    "Purge the cache": "清除缓存",
    "Show the link to settings": "显示设置链接",
    "The menu is enabled by default for users": "用户的默认菜单已激活",
    "Except when the configuration is forced.": "除非设置被强制使用。",
    "Apps that should not be displayed in the menu": "禁止在菜单中显示的应用",
    "This feature is only compatible with the <code>big menu<\/code> display.": "此功能只和<code>大型菜单<\/code>兼容。",
    "The logo is a link to the default app": "logo链接到默认应用",
    "Others": "其他",
    "Categories": "类别",
    "Customize sorting": "自定义顺序",
    "Order by": "排序规则",
    "Name": "名称",
    "Customed": "自定义",
    "Show and hide the list of categories": "显示或隐藏类别列表",
    "This parameters are used when Dark theme or Breeze Dark Theme are enabled.": "此参数将应用于暗黑主题激活时。",
    "Dark mode colors": "暗黑模式颜色",
    "With categories": "有类别"
}, "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> side_menu_v2.3.4.tar.gz: side_menu/l10n/zh_CN.js <==
OC.L10N.register("side_menu", {
    "Custom menu": "自定义菜单",
    "Enable the custom menu": "激活自定义菜单",
    "No": "取消",
    "Yes": "确定",
    "Menu": "菜单",
    "Use the shortcut <span class=\"keyboard-key\">Ctrl<\/span>+<span class=\"keyboard-key\">o<\/span> to open and to hide the side menu. Use <span class=\"keyboard-key\">tab<\/span> to navigate.": "使用快捷键 <span class=\"keyboard-key\">Ctrl<\/span>+<span class=\"keyboard-key\">o<\/span> 打开或隐藏侧边栏菜单。使用<span class=\"keyboard-key\">tab<\/span> 来导航。",
    "Top menu": "顶部菜单",
    "Apps that not must be moved in the side menu": "禁止在侧边栏菜单移动的应用",
    "If there is no selection then the global configuration is applied.": "如不选择，将应用全局设定。",
    "Experimental": "实验性",
    "Save": "保存",
    "You like this app and you want to support me?": "喜欢本应用并支持我一下？",
    "Buy me a coffee ☕": "赏一杯咖啡 ☕ 给我",
    "Hidden": "隐藏",
    "Small": "小型",
    "Normal": "标准",
    "Big": "大型",
    "Colors": "颜色",
    "Background color": "背景颜色",
    "Background color of current app": "当前应用的背景色",
    "Text color": "文字颜色",
    "Loader": "菜单指示器",
    "Icon": "图标",
    "Same color": "相同颜色",
    "Opposite color": "相反颜色",
    "Transparent": "透明",
    "Opaque": "不透明",
    "Opener": "容器",
    "Default": "默认",
    "Default (dark)": "默认(深色)",
    "Hamburger": "Hamburger",
    "Hamburger (dark)": "Hamburger (深色)",
    "Hamburger 2": "Hamburger 2",
    "Hamburger 2 (dark)": "Hamburger 2 (深色)",
    "Before the logo": "在logo前",
    "After the logo": "在logo后",
    "Position": "位置",
    "Show only the opener (hidden logo)": "只显示容器 (隐藏logo)",
    "Do not display the side menu and the opener if there is no application (eg: public pages).": "N如果没有应用，不显示侧边栏菜单和容器 (例如 : 公共页面)。",
    "Panel": "面板",
    "Open the menu when the mouse is hover the opener (automatically disabled on touch screens)": "鼠标悬停时打开菜单 (触摸屏时将自动禁用)",
    "Display the big menu": "显示大型菜单",
    "This menu is not compatible with AppOrder.": "型菜单与应用顺序不兼容",
    "Display the logo": "显示logo",
    "This feature is not compatible with the <code>big menu<\/code> display.": "此功能与显示<code>大型菜单<\/code>不兼容。",
    "Icons and texts": "图标与文字",
    "Loader enabled": "菜单指示器已激活",
    "Tips": "技巧",
    "Always displayed": "一直显示",
    "The logo will be hidden when the menu is always displayed.": "一直显示菜单时logo将被隐藏。",
    "This is the automatic behavior when the menu is always displayed.": "一直显示菜单时的自动动作。",
    "Not compatible with touch screens.": "与触屏不兼容。",
    "Big menu": "大型菜单",
    "Live preview": "实时预览",
    "Open apps in new tab": "在新标签中打开应用",
    "Use the global setting": "使用全局设定",
    "Use my selection": "使用自定义设定",
    "Show and hide the list of applications": "显示或隐藏应用列表",
    "Use the avatar instead of the logo": "使用头像代替logo",
    "You do not have permission to change the settings.": "没有更改设置的权限。",
    "Force this configuration to users": "强制用户使用此设置",
    "Export the configuration": "导出设置",
    "Purge the cache": "清除缓存",
    "Show the link to settings": "显示设置链接",
    "The menu is enabled by default for users": "用户的默认菜单已激活",
    "Except when the configuration is forced.": "除非设置被强制使用。",
    "Apps that should not be displayed in the menu": "禁止在菜单中显示的应用",
    "This feature is only compatible with the <code>big menu<\/code> display.": "此功能只和<code>大型菜单<\/code>兼容。",
    "The logo is a link to the default app": "logo链接到默认应用",
    "Others": "其他",
    "Categories": "类别",
    "Customize sorting": "自定义顺序",
    "Order by": "排序规则",
    "Name": "名称",
    "Customed": "自定义",
    "Show and hide the list of categories": "显示或隐藏类别列表",
    "This parameters are used when Dark theme or Breeze Dark Theme are enabled.": "此参数将应用于暗黑主题激活时。",
    "Dark mode colors": "暗黑模式颜色",
    "With categories": "有类别",
    "Custom categories": "自定义类别",
    "Customize application categories": "自定义应用程序类别",
    "Apps only visible in the top menu": "应用程序仅在顶部菜单中可见",
    "Apps visible in the top and side menus": "顶部和侧边菜单中可见的应用程序"
}, "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
